@@ -58,9 +58,10 @@ def compute_difference_confidence_interval(
         whether to clip the confidence interval to the interval (-1, 1).
     sides: str or int, default "two-sided",
         the sides of the confidence interval, should be one of
-        "two-sided" (aliases "2-sided", "two_sided", "2_sided", "2-sides", "two_sides", "two-sides", "2_sides", "ts", "t", "two", "2", 2),
-        "left-sided" (aliases "left_sided", "left", "ls", "l"),
-        "right-sided" (aliases "right_sided", "right", "rs", "r"),
+        - "two-sided" (aliases "2-sided", "two_sided", "2_sided", "2-sides",
+            "two_sides", "two-sides", "2_sides", "ts", "t", "two", "2", 2),
+        - "left-sided" (aliases "left_sided", "left", "ls", "l"),
+        - "right-sided" (aliases "right_sided", "right", "rs", "r"),
         case insensitive.
 
     Returns
@@ -72,47 +73,49 @@ def compute_difference_confidence_interval(
 
     if confint_type not in _supported_types:
         raise ValueError(
-            f"confint_type should be one of {_supported_types}, "
-            f"but got {confint_type}"
+            f"`method` should be one of `{_supported_types}`, "
+            f"but got `{confint_type}`"
         )
 
     if conf_level <= 0 or conf_level >= 1:
         raise ValueError(
-            f"conf_level should be inside the interval (0, 1), " f"but got {conf_level}"
+            f"`conf_level` should be inside the interval (0, 1), but got `{conf_level}`"
         )
 
     if n_positive > n_total:
         raise ValueError(
-            f"n_positive should be less than or equal to n_total, "
-            f"but got n_positive={n_positive} and n_total={n_total}"
+            f"`n_positive` should be less than or equal to `n_total`, "
+            f"but got `n_positive={n_positive}` and `n_total={n_total}`"
         )
 
     if ref_positive > ref_total:
         raise ValueError(
-            f"ref_positive should be less than or equal to ref_total, "
-            f"but got ref_positive={ref_positive} and ref_total={ref_total}"
+            f"`ref_positive` should be less than or equal to `ref_total`, "
+            f"but got `ref_positive={ref_positive}` and `ref_total={ref_total}`"
         )
 
     if n_positive < 0:
         raise ValueError(
-            f"n_positive should be non-negative, but got n_positive={n_positive}"
+            f"`n_positive` should be non-negative, but got `n_positive={n_positive}`"
         )
 
     if n_total <= 0:
-        raise ValueError(f"n_total should be positive, but got n_total={n_total}")
+        raise ValueError(f"`n_total` should be positive, but got `n_total={n_total}`")
 
     if ref_positive < 0:
         raise ValueError(
-            f"ref_positive should be non-negative, but got ref_positive={ref_positive}"
+            f"`ref_positive` should be non-negative, but got `ref_positive={ref_positive}`"
         )
 
     if ref_total <= 0:
-        raise ValueError(f"ref_total should be positive, but got ref_total={ref_total}")
+        raise ValueError(
+            f"`ref_total` should be positive, but got `ref_total={ref_total}`"
+        )
 
     sides = str(sides).lower()
     if sides not in _SIDE_NAME_MAP:
         raise ValueError(
-            f"sides should be one of {list(_SIDE_NAME_MAP)}, but got {sides}"
+            f"`sides` should be one of `{list(_SIDE_NAME_MAP)}`, but got `{sides}`"
         )
     else:
         sides = _SIDE_NAME_MAP[sides]
@@ -380,23 +383,23 @@ def _compute_difference_confidence_interval(
             lower, upper, delta_ratio, conf_level, confint_type.lower(), str(sides)
         )
     elif confint_type.lower() == "exact":
-        raise NotImplementedError
+        raise NotImplementedError(f"`method` `{confint_type}` is not implemented yet")
     elif confint_type.lower() == "mid-p":
-        raise NotImplementedError
+        raise NotImplementedError(f"`method` `{confint_type}` is not implemented yet")
     elif confint_type.lower() == "santner-snell":
-        raise NotImplementedError
+        raise NotImplementedError(f"`method` `{confint_type}` is not implemented yet")
     elif confint_type.lower() == "chan-zhang":
-        raise NotImplementedError
+        raise NotImplementedError(f"`method` `{confint_type}` is not implemented yet")
     elif confint_type.lower() == "agresti-min":
-        raise NotImplementedError
+        raise NotImplementedError(f"`method` `{confint_type}` is not implemented yet")
     elif confint_type.lower() == "wang":
-        raise NotImplementedError
+        raise NotImplementedError(f"`method` `{confint_type}` is not implemented yet")
     elif confint_type.lower() == "pradhan-banerjee":
-        raise NotImplementedError
+        raise NotImplementedError(f"`method` `{confint_type}` is not implemented yet")
     else:
         newline = "\n"
         raise ValueError(
-            f"""{confint_type} is not supported, """
+            f"""`method` `{confint_type}` is not supported, """
             f"""choose one from {newline}{newline.join(_supported_types)}"""
         )
 
