@@ -7,20 +7,23 @@ from pathlib import Path
 from typing import List
 
 import pandas as pd
-from pytest import approx, raises
+from pytest import approx, raises, warns
 
 from diff_binom_confint import compute_confidence_interval
 from diff_binom_confint._binom_confint import (
     _supported_methods,
     _method_aliases,
     _stochastic_methods,
+    _compute_confidence_interval,
+    list_confidence_interval_types,
+    list_confidence_interval_methods,
 )
 
 
 _TEST_DATA_DIR = Path(__file__).parent / "test-data"
 
 
-def load_test_data() -> List[pd.DataFrame]:
+def test_load_data() -> List[pd.DataFrame]:
     test_file_pattern = "example-(?P<n_positive>[\\d]+)-(?P<n_total>[\\d]+)\\.csv"
     test_files = Path(_TEST_DATA_DIR).glob("*.csv")
     test_data = []
@@ -134,21 +137,81 @@ def test_confidence_interval():
             row["upper_bound"], abs=error_bound
         ), f"for {confint_method}, upper bound should be {row['upper_bound']:.2%}, but got {upper:.2%}"
 
+    # "witting" is not tested in the above, since no test data is available
+    lower, upper = compute_confidence_interval(
+        n_positive,
+        n_total,
+        conf_level=0.975,
+        method="witting",
+        sides="left",
+    ).astuple()
+    assert (
+        upper == 1
+    ), f"for `witting`, upper bound should be {1.0:.2%}, but got {upper:.2%}"
+    lower, upper = compute_confidence_interval(
+        n_positive,
+        n_total,
+        conf_level=0.975,
+        method="witting",
+        sides="right",
+    ).astuple()
+    assert (
+        lower == 0
+    ), f"for `witting`, lower bound should be {0.0:.2%}, but got {lower:.2%}"
+
+    # several edge cases are not covered in the loop
+    # TODO add assertions for these edge cases
+    for n_positive, n_total in [[0, 1], [1, 1], [2, 2], [2, 3]]:
+        compute_confidence_interval(
+            n_positive=n_positive,
+            n_total=n_total,
+            method="pratt",
+        )
+    for n_positive, n_total in [[0, 1], [1, 1]]:
+        compute_confidence_interval(
+            n_positive=n_positive,
+            n_total=n_total,
+            method="mid-p",
+        )
+    for n_positive, n_total in [[1, 50], [49, 50]]:
+        compute_confidence_interval(
+            n_positive=n_positive,
+            n_total=n_total,
+            method="modified-wilson",
+        )
+    for n_positive, n_total in [[1, 1], [1, 2]]:
+        compute_confidence_interval(
+            n_positive=n_positive,
+            n_total=n_total,
+            method="modified-jeffreys",
+        )
+
     print("test_confidence_interval passed")
 
 
+def test_list_confidence_interval_methods():
+    assert list_confidence_interval_methods() is None  # print to stdout
+
+    with warns(DeprecationWarning):
+        assert list_confidence_interval_types() is None  # print to stdout
+
+
 def test_errors():
-    with raises(ValueError, match="confint_type should be one of"):
+    with raises(ValueError, match="`method` should be one of"):
         compute_confidence_interval(1, 2, method="not-supported")
     with raises(
-        ValueError, match="conf_level should be inside the interval \\(0, 1\\)"
+        ValueError, match="`conf_level` should be inside the interval \\(0, 1\\)"
     ):
         compute_confidence_interval(1, 2, conf_level=0)
-    with raises(ValueError, match="n_positive should be less than or equal to n_total"):
+    with raises(
+        ValueError, match="`n_positive` should be less than or equal to `n_total`"
+    ):
         compute_confidence_interval(2, 1)
-    with raises(ValueError, match="n_positive should be non-negative"):
+    with raises(ValueError, match="`n_positive` should be non-negative"):
         compute_confidence_interval(-1, 1)
-    with raises(ValueError, match="n_total should be positive"):
+    with raises(ValueError, match="`n_total` should be positive"):
         compute_confidence_interval(0, 0)
-    with raises(ValueError, match="sides should be one of"):
+    with raises(ValueError, match="`sides` should be one of"):
         compute_confidence_interval(1, 2, sides="3-sided")
+    with raises(ValueError, match="`method` `not-supported` is not supported"):
+        _compute_confidence_interval(1, 2, confint_type="not-supported")
